@@ -42,7 +42,7 @@ import qualified System.Posix as Posix
 traverse :: MonadIO m
          => Bool -- ^ Follow directory symlinks (only used on POSIX platforms)
          -> FilePath -- ^ Root directory
-         -> GSource m FilePath
+         -> Producer m FilePath
 traverse _followSymlinks root =
     liftIO (listDirectory root) >>= pull
   where
@@ -75,11 +75,11 @@ traverse _followSymlinks root =
 -- | Same as 'CB.sourceFile', but uses system-filepath\'s @FilePath@ type.
 sourceFile :: MonadResource m
            => FilePath
-           -> GSource m S.ByteString
+           -> Producer m S.ByteString
 sourceFile = CB.sourceFile . encodeString
 
 -- | Same as 'CB.sinkFile', but uses system-filepath\'s @FilePath@ type.
 sinkFile :: MonadResource m
          => FilePath
-         -> GInfSink S.ByteString m
+         -> Consumer S.ByteString m ()
 sinkFile = CB.sinkFile . encodeString
